@@ -18,8 +18,14 @@ TIMESTRING_RE = re.compile(re.sub('[\t\n\s]', '', re.sub('(\(\?\#[^\)]+\))', '',
                         |
 
                     (?# =-=-=-= Matches "january 5, 2012", "january 5th, '12", "jan 5th 2012" =-=-=-= )
-                    ((?P<month>january|february|march|april|june|july|august|september|october|november|december|jan|feb|mar|apr|may|jun|jul|aug|sept?|oct|nov|dec)\s((?P<date>\d{1,2})(th|nd|st|rd)?)(,?\s(?P<year>([12][089]|')?\d{2}))?)
-                        |
+                    (
+                        ((?P<year_6>(([12][089])|')\d{2})?([\/\-\s]+)?)
+                        (?P<month>january|february|march|april|june|july|august|september|october|november|december|jan|feb|mar|apr|may|jun|jul|aug|sept?|oct|nov|dec)[\/\-\s]
+                        ((?P<date>\d{1,2})(th|nd|st|rd)?)
+                        (,?\s(?P<year>([12][089]|')?\d{2}))?
+                    )
+
+                    |
 
                     (?# =-=-=-= Matches "2012/12/11", "5/23/2012", "05/2012", "2012" =-=-=-= )
                     (
